
%define api.pure
%parse-param { struct pcdata * pp }
%name-prefix="fixc_"

%{

#include <stdarg.h>

#define YYERROR_VERBOSE

void yyerror(void *, char *, ...);

#if YYDEBUG != 0
extern int yydebug;
#endif

%}

%union{
    char * s;
}


%{
#include "scanner.h"
#include "pure.h"
#define YYLEX_PARAM pp->scaninfo
%}

%token INCLUDE NEWLINE DEFINE
%token <s> STRING

%%

includes: /* empty file */
	| includes include

include : INCLUDE STRING
	{
		int i, len;

		len = strlen($2);
		for(i = 0; i < len; ++i){
			if($2[i] == '\\'){
				$2[i] = '/';
			}
		}
	
		printf("%s", $2);
		free($2);
	}
	| INCLUDE DEFINE

%%

int yy_parse_includes_fp(FILE * fp)
{
	struct pcdata p = {0, 0};
	int rc;

#if YYDEBUG != 0
	yydebug = 1;
#endif

	p.fn = "unknown";

	fixc_lex_init(&p.scaninfo);
	fixc_set_in(fp, p.scaninfo);

	rc = !yyparse(&p);

	fixc_lex_destroy(p.scaninfo);

	return rc;
}

int yy_parse_includes(char const * fn)
{
	struct pcdata p = {0, 0};
	int rc = 0;
	FILE * in;

#if YYDEBUG != 0
	yydebug = 1;
#endif
	in = fopen(fn, "r");

	if(in){
		p.fn = fn;

		fixc_lex_init(&p.scaninfo);
		fixc_set_in(in, p.scaninfo);
	
		rc = !yyparse(&p);

		fixc_lex_destroy(p.scaninfo);

		fclose(in);
	}

	return rc;
}


void yyerror(void * vp, char * s, ...)
{
    struct pcdata * p = (struct pcdata*)vp;
    va_list ap;
    va_start(ap, s);
    fprintf(stderr, "%s:%d: Error ", p->fn, fixc_get_lineno(p->scaninfo));
    vfprintf(stderr, s, ap);
    fprintf(stderr, "\n");
}

